@@ -1,12 +1,11 @@
 char *s = N_("A GNOME applet project");
 char *s = N_("A generic C++ project");
-char *s = N_("A generic GNOME project");
 char *s = N_("A generic GTK+ project");
 char *s = N_("A generic GTKmm (C++) project");
 char *s = N_("A generic Xlib dock applet");
 char *s = N_("A generic Xlib project");
 char *s = N_("A generic java project using automake project management");
-char *s = N_("A generic minimal and flat project ");
+char *s = N_("A generic minimal and flat project");
 char *s = N_("A generic natively compiled java project using the GNU Java Compiler (gcj)");
 char *s = N_("A generic project");
 char *s = N_("A generic python project using automake project management");
@@ -40,7 +39,6 @@ char *s = N_("Django Project");
 char *s = N_("Django Project information");
 char *s = N_("Email address:");
 char *s = N_("GCJ needs to know which class contains the main() function");
-char *s = N_("GNOME");
 char *s = N_("GNOME Applet");
 char *s = N_("GTK+");
 char *s = N_("GTKmm");
@@ -97,9 +95,7 @@ char *s = N_("Require SDL_ttf:");
 char *s = N_("SDL");
 char *s = N_("Select code license");
 char *s = N_("Shell values to watch");
-char *s = N_("Use libglade for the UI");
 char *s = N_("Use pkg-config to add library support from other packages");
-char *s = N_("Use the libglade-2.0 library to load the glade interface file at runtime");
 char *s = N_("Value Name:");
 char *s = N_("Values to watch");
 char *s = N_("Version:");
