@@ -22,8 +22,6 @@
  * 	Boston, MA  02110-1301, USA.
  */
 
-
-
 #include <config.h>
 #include <gio/gio.h>
 #include <libanjuta/anjuta-shell.h>
@@ -47,9 +45,10 @@
 #include "symbol-db-view-search.h"
 #include "symbol-db-engine.h"
 #include "symbol-db-prefs.h"
+#include "symbol-db-iface.h"
 
 #define ICON_FILE "anjuta-symbol-db-plugin-48.png"
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-symbol-db-plugin.ui"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-symbol-db-plugin.xml"
 
 #define TIMEOUT_INTERVAL_SYMBOLS_UPDATE		10
 #define TIMEOUT_SECONDS_AFTER_LAST_TIP		5
@@ -327,9 +326,11 @@ static GtkActionEntry actions[] =
 };
 
 static GtkActionEntry actions_search[] = {
-  { "ActionEditSearchFindSymbol", GTK_STOCK_FIND, N_("_Find Symbol..."),
+  { 
+	"ActionEditSearchFindSymbol", GTK_STOCK_FIND, N_("_Find Symbol..."),
 	"<control>l", N_("Find Symbol"),
-    G_CALLBACK (on_find_symbol)}
+    G_CALLBACK (on_find_symbol)
+  }
 };
 
 static void
@@ -673,7 +674,7 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	g_free (local_path);
 	
 	/* add a default timeout to the updating of buffer symbols */	
-	tags_update = anjuta_preferences_get_int (sdb_plugin->prefs, BUFFER_AUTOSCAN);
+	tags_update = anjuta_preferences_get_bool (sdb_plugin->prefs, BUFFER_AUTOSCAN);
 				
 	if (tags_update)
 		sdb_plugin->buf_update_timeout_id = 
@@ -683,68 +684,6 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	sdb_plugin->need_symbols_update = FALSE;
 }
 
-static void
-on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
-				 AnjutaSession *session,
-				 SymbolDBPlugin *sdb_plugin)
-{
-	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
-		return;
-
-	DEBUG_PRINT ("%s", "SymbolDB: session_save");
-
-	anjuta_session_set_string_list (session, 
-									SESSION_SECTION, 
-									SESSION_KEY,
-									sdb_plugin->session_packages);	
-}
-
-static void
-on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
-				 AnjutaSession *session,
-				 SymbolDBPlugin *sdb_plugin)
-{
-	IAnjutaProjectManager *pm;
-	pm = anjuta_shell_get_interface (ANJUTA_PLUGIN (sdb_plugin)->shell,
-									 IAnjutaProjectManager, NULL);	
-	
-	if (phase == ANJUTA_SESSION_PHASE_START)
-	{
-		sdb_plugin->session_packages = anjuta_session_get_string_list (session, 
-																	   SESSION_SECTION, 
-																	   SESSION_KEY);
-	
-		DEBUG_PRINT ("SymbolDB: session_loading started. Getting info from %s",
-					 anjuta_session_get_session_directory (session));
-		sdb_plugin->session_loading = TRUE;
-	}
-	
-	else if (phase == ANJUTA_SESSION_PHASE_END)
-	{
-		IAnjutaDocumentManager* docman;
-		sdb_plugin->session_loading = FALSE;
-		DEBUG_PRINT ("SymbolDB: session_loading finished");
-		
-		/* Show the symbols for the current editor */
-		docman = anjuta_shell_get_interface (shell, IAnjutaDocumentManager, NULL);
-		if (docman)
-		{
-			IAnjutaDocument* cur_doc = 
-				ianjuta_document_manager_get_current_document (docman, NULL);
-			if (cur_doc)
-			{
-				GValue value = {0, };
-				g_value_init (&value, G_TYPE_OBJECT);
-				g_value_set_object (&value, cur_doc);
-				value_added_current_editor (ANJUTA_PLUGIN (sdb_plugin),
-											"document_manager_current_document",
-											&value, NULL);
-				g_value_unset(&value);
-			}
-		}
-	}	
-}
-
 static void
 on_editor_foreach_disconnect (gpointer key, gpointer value, gpointer user_data)
 {	
@@ -1502,7 +1441,7 @@ do_import_system_sources (SymbolDBPlugin *sdb_plugin)
 	/* the resume thing */
 	GPtrArray *sys_src_array = NULL;
 	sys_src_array = 
-		symbol_db_engine_get_files_with_zero_symbols (sdb_plugin->sdbe_globals);
+		symbol_db_util_get_files_with_zero_symbols (sdb_plugin->sdbe_globals);
 
 	if (sys_src_array != NULL && sys_src_array->len > 0) 
 	{
@@ -1643,7 +1582,7 @@ do_check_offline_files_changed (SymbolDBPlugin *sdb_plugin)
 				symbol_db_engine_iterator_node_get_symbol_extra_string (dbin,
 													SYMINFO_FILE_PATH);
 			
-			if (g_hash_table_remove (prj_elements_hash, file) == FALSE)
+			if (file && g_hash_table_remove (prj_elements_hash, file) == FALSE)
 			{
 				/* hey, we dind't find an element to remove the the project list.
 				 * So, probably, this is a new file added in offline mode via Makefile.am
@@ -1718,6 +1657,96 @@ do_check_offline_files_changed (SymbolDBPlugin *sdb_plugin)
 	return real_added > 0 ? TRUE : FALSE;	
 }
 
+static void
+on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
+				 AnjutaSession *session,
+				 SymbolDBPlugin *sdb_plugin)
+{
+	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
+		return;
+
+	DEBUG_PRINT ("%s", "SymbolDB: session_save");
+
+	anjuta_session_set_string_list (session, 
+									SESSION_SECTION, 
+									SESSION_KEY,
+									sdb_plugin->session_packages);	
+}
+
+static void
+on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
+				 AnjutaSession *session,
+				 SymbolDBPlugin *sdb_plugin)
+{
+	IAnjutaProjectManager *pm;
+	pm = anjuta_shell_get_interface (ANJUTA_PLUGIN (sdb_plugin)->shell,
+									 IAnjutaProjectManager, NULL);	
+	
+	if (phase == ANJUTA_SESSION_PHASE_START)
+	{
+		sdb_plugin->session_packages = anjuta_session_get_string_list (session, 
+																	   SESSION_SECTION, 
+																	   SESSION_KEY);
+	
+		DEBUG_PRINT ("SymbolDB: session_loading started. Getting info from %s",
+					 anjuta_session_get_session_directory (session));
+		sdb_plugin->session_loading = TRUE;
+		
+		if (sdb_plugin->session_packages == NULL)
+		{
+			/* hey, does user want to import system sources for this project? */
+			gboolean automatic_scan = anjuta_preferences_get_bool (sdb_plugin->prefs, 
+																  PROJECT_AUTOSCAN);
+			
+			if (automatic_scan == TRUE)
+			{
+				sdb_plugin->session_packages = ianjuta_project_manager_get_packages (pm, NULL);
+			}
+		}
+		
+		/* get preferences about the parallel scan */
+		gboolean parallel_scan = anjuta_preferences_get_bool (sdb_plugin->prefs, 
+															 PARALLEL_SCAN); 
+		
+		if (parallel_scan == TRUE && 
+			symbol_db_engine_is_connected (sdb_plugin->sdbe_globals) == TRUE)
+		{
+			/* we simulate a project-import-end signal received */
+			do_import_system_sources (sdb_plugin);
+		}
+	}	
+	else if (phase == ANJUTA_SESSION_PHASE_END)
+	{
+		IAnjutaDocumentManager* docman;
+		sdb_plugin->session_loading = FALSE;
+		DEBUG_PRINT ("SymbolDB: session_loading finished");
+		
+		/* Show the symbols for the current editor */
+		docman = anjuta_shell_get_interface (shell, IAnjutaDocumentManager, NULL);
+		if (docman)
+		{
+			IAnjutaDocument* cur_doc = 
+				ianjuta_document_manager_get_current_document (docman, NULL);
+			if (cur_doc)
+			{
+				GValue value = {0, };
+				g_value_init (&value, G_TYPE_OBJECT);
+				g_value_set_object (&value, cur_doc);
+				value_added_current_editor (ANJUTA_PLUGIN (sdb_plugin),
+											"document_manager_current_document",
+											&value, NULL);
+				g_value_unset(&value);
+			}
+		}
+		
+		if (sdb_plugin->project_opened == NULL)
+		{
+			gtk_widget_hide (sdb_plugin->progress_bar_project);
+			gtk_widget_hide (sdb_plugin->progress_bar_system);
+		}
+	}	
+}
+
 /* add a new project */
 static void
 on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
@@ -1754,7 +1783,6 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 												 sdb_plugin->sdbe_globals);		
 	}
 	
-	
 	/* Hide the progress bar. Default system tags thing: we'll import after abort even 
 	 * if the preferences says not to automatically scan the packages.
 	 */
@@ -1763,30 +1791,6 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	pm = anjuta_shell_get_interface (ANJUTA_PLUGIN (sdb_plugin)->shell,
 									 IAnjutaProjectManager, NULL);
 	
-	if (sdb_plugin->session_packages == NULL)
-	{
-		/* hey, does user want to import system sources for this project? */
-		gboolean automatic_scan = anjuta_preferences_get_int (sdb_plugin->prefs, 
-															  PROJECT_AUTOSCAN);
-		
-		if (automatic_scan == TRUE)
-		{
-			sdb_plugin->session_packages = ianjuta_project_manager_get_packages (pm, NULL);
-		}
-	}
-
-	/* get preferences about the parallel scan */
-	gboolean parallel_scan = anjuta_preferences_get_int (sdb_plugin->prefs, 
-														 PARALLEL_SCAN); 
-	
-	if (parallel_scan == TRUE)
-	{
-		/* we simulate a project-import-end signal received */
-		do_import_system_sources (sdb_plugin);		
-	}
-	
-	
-	
 	/*
 	 *   The Project thing
 	 */	
@@ -1874,7 +1878,7 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 			
 			
 			sources_array = 
-				symbol_db_engine_get_files_with_zero_symbols (sdb_plugin->sdbe_project);
+				symbol_db_util_get_files_with_zero_symbols (sdb_plugin->sdbe_project);
 
 			if (sources_array != NULL && sources_array->len > 0) 
 			{				
@@ -2013,7 +2017,7 @@ on_scan_end_manager (SymbolDBEngine *dbe, gint process_id,
 										  sdb_plugin);
 			
 			/* get preferences about the parallel scan */
-			gboolean parallel_scan = anjuta_preferences_get_int (sdb_plugin->prefs, 
+			gboolean parallel_scan = anjuta_preferences_get_bool (sdb_plugin->prefs, 
 														 PARALLEL_SCAN); 
 			
 			do_check_languages_count (sdb_plugin);
@@ -2202,7 +2206,6 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	sdb_plugin->progress_bar_system = gtk_progress_bar_new();
 	gtk_progress_bar_set_ellipsize (GTK_PROGRESS_BAR(sdb_plugin->progress_bar_system),
 									PANGO_ELLIPSIZE_MIDDLE);
-	
 	g_object_ref (sdb_plugin->progress_bar_system);
 		
 	gtk_box_pack_start (GTK_BOX (sdb_plugin->dbv_main), sdb_plugin->dbv_notebook,
@@ -2213,6 +2216,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 						FALSE, FALSE, 0);	
 	gtk_widget_show_all (sdb_plugin->dbv_main);
 	
+
 	/* Local symbols */
 	sdb_plugin->scrolled_locals = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sdb_plugin->scrolled_locals),
@@ -2545,242 +2549,6 @@ symbol_db_class_init (GObjectClass *klass)
 						g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);	
 }
 
-static IAnjutaIterable*
-isymbol_manager_search (IAnjutaSymbolManager *sm,
-						IAnjutaSymbolType match_types,
-						gboolean include_types,
-						IAnjutaSymbolField info_fields,
-						const gchar *match_name,
-						gboolean partial_name_match,
-						gboolean global_symbols_search,
-						gboolean global_tags_search,
-						gint results_limit,
-						gint results_offset,
-						GError **err)
-{
-	SymbolDBEngineIterator *iterator = NULL;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe_project;
-	SymbolDBEngine *dbe_globals;
-	GPtrArray *filter_array;
-	gchar *pattern;
-	gboolean exact_match = !partial_name_match;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe_project = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-	dbe_globals = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_globals);
-	
-	if (match_types & IANJUTA_SYMBOL_TYPE_UNDEF)
-	{
-		filter_array = NULL;
-		/*DEBUG_PRINT ("%s", "filter_array is NULL");*/
-	}
-	else 
-	{
-		filter_array = symbol_db_engine_fill_type_array (match_types);
-		/*DEBUG_PRINT ("filter_array filled with %d kinds", filter_array->len);*/
-	}
-
-	if (exact_match == FALSE)
-		pattern = g_strdup_printf ("%s%%", match_name == NULL ? "" : match_name);
-	else
-	{
-		if (match_name == NULL)
-			pattern = NULL;
-		else
-			pattern = g_strdup_printf ("%s", match_name);
-	}
-	
-	/* should we lookup for project of system tags? */
-	iterator = 
-		symbol_db_engine_find_symbol_by_name_pattern_filtered (
-					global_tags_search == FALSE ? dbe_project : dbe_globals, 
-					pattern,
-					exact_match,
-					filter_array,
-					include_types,
-					global_symbols_search,
-					global_tags_search == FALSE ? NULL : sdb_plugin->session_packages,
-					results_limit,
-					results_offset,
-					info_fields);	
-	g_free (pattern);
-	
-	if (filter_array)
-	{
-		g_ptr_array_foreach (filter_array, (GFunc)g_free, NULL);
-		g_ptr_array_free (filter_array, TRUE);
-	}
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_members (IAnjutaSymbolManager *sm,
-							 const IAnjutaSymbol *symbol, 
-							 IAnjutaSymbolField info_fields,
-							 gboolean global_search,
-							 GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	gint sym_id;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-	
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (symbol);
-	
-	sym_id = symbol_db_engine_iterator_node_get_symbol_id (node);
-	
-	iterator = symbol_db_engine_get_scope_members_by_symbol_id (dbe,
-																sym_id,
-																-1, 
-																-1,
-																info_fields);
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_class_parents (IAnjutaSymbolManager *sm,
-							 const IAnjutaSymbol *symbol,
-							 IAnjutaSymbolField info_fields,
-							 GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	gint sym_id;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-	
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (symbol);
-	
-	sym_id = symbol_db_engine_iterator_node_get_symbol_id (node);
-	
-	iterator = symbol_db_engine_get_class_parents_by_symbol_id (dbe, 
-																sym_id, 
-																info_fields);
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_scope (IAnjutaSymbolManager *sm,
-						   const gchar* filename,  
-						   gulong line,  
-						   IAnjutaSymbolField info_fields, 
-						   GError **err)
-{
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-	
-	iterator = symbol_db_engine_get_current_scope (dbe, filename, line, info_fields);
-	
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_parent_scope (IAnjutaSymbolManager *sm,
-								  const IAnjutaSymbol *symbol, 
-								  const gchar *filename, 
-								  IAnjutaSymbolField info_fields,
-								  GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	gint child_node_id, parent_node_id;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (symbol);
-	
-	child_node_id = symbol_db_engine_iterator_node_get_symbol_id (node);
-	
-	if (child_node_id <= 0)
-		return NULL;
-	
-	parent_node_id = symbol_db_engine_get_parent_scope_id_by_symbol_id (dbe,
-									child_node_id,
-									filename);
-
-	iterator = symbol_db_engine_get_symbol_info_by_id (dbe, parent_node_id, 
-													   info_fields);
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_symbol_more_info (IAnjutaSymbolManager *sm,
-								  const IAnjutaSymbol *symbol, 
-								  IAnjutaSymbolField info_fields,
-								  GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	gint node_id;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (symbol);
-	
-	node_id = symbol_db_engine_iterator_node_get_symbol_id (node);
-	
-	if (node_id <= 0)
-		return NULL;
-	
-	iterator = symbol_db_engine_get_symbol_info_by_id (dbe, node_id, info_fields);	
-	
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaSymbol*
-isymbol_manager_get_symbol_by_id (IAnjutaSymbolManager *sm,
-								  gint symbol_id, 
-								  IAnjutaSymbolField info_fields,
-								  GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-
-	g_return_val_if_fail (symbol_id > 0, NULL);
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-
-	iterator = symbol_db_engine_get_symbol_info_by_id (dbe, symbol_id, 
-													   info_fields);	
-	
-	if (iterator == NULL)
-		return NULL;
-	
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (iterator);
-	return IANJUTA_SYMBOL (node);	
-}
-
-static void
-isymbol_manager_iface_init (IAnjutaSymbolManagerIface *iface)
-{
-	iface->search = isymbol_manager_search;
-	iface->get_members = isymbol_manager_get_members;
-	iface->get_class_parents = isymbol_manager_get_class_parents;
-	iface->get_scope = isymbol_manager_get_scope;
-	iface->get_parent_scope = isymbol_manager_get_parent_scope;
-	iface->get_symbol_more_info = isymbol_manager_get_symbol_more_info;
-	iface->get_symbol_by_id = isymbol_manager_get_symbol_by_id;
-}
 
 
 static void
@@ -2846,8 +2614,7 @@ on_prefs_buffer_update_toggled (SymbolDBPrefs *sdbp, guint value,
 									   on_editor_buffer_symbols_update_timeout,
 									   sdb_plugin);			
 		
-	}
-	
+	}	
 }
 
 static void
